Exception: Twitter::ForbiddenError

Inherits:
RESTError
  • Object
show all
Defined in:
lib/twitter/core.rb

Overview

Runtime error leaf class raised when update limit reached. HTTP code: 403 (aka Forbidden).

To handle specifically you would do the following: begin timeline = twitter.timeline_for(:friends, :since => tweet) rescue ForbiddenError => fe

do something to notify user that update limit has been reached

end

Instance Attribute Summary

Attributes inherited from RESTError

#code, #error, #message, #uri

Method Summary

Methods inherited from RESTError

register, registry, #to_s

Methods included from ClassUtilMixin

included