Exception: Twitter::NotAcceptableError

Inherits:
RESTError
  • Object
show all
Defined in:
lib/twitter/core.rb

Overview

Runtime error leaf class raised when the format specified in the request is not understood by the Twitter.com API. HTTP code: 406 (aka Not Acceptable).

To handle specifically you would do the following: begin timeline = twitter.timeline_for(:friends, :since => tweet) rescue NotAcceptableError => nae

end

Instance Attribute Summary

Attributes inherited from RESTError

#code, #error, #message, #uri

Method Summary

Methods inherited from RESTError

register, registry, #to_s

Methods included from ClassUtilMixin

included