Exception: Twitter::NotFoundError

Inherits:
RESTError
  • Object
show all
Defined in:
lib/twitter/core.rb

Overview

Runtime error leaf class raised when a resource requested was not found. HTTP code: 404 (aka Not Found).

To handle specifically you would do the following: begin timeline = twitter.timeline_for(:friends, :since => tweet) rescue NotFoundError => nfe

do something to notify user that resource was not found.

end

Instance Attribute Summary

Attributes inherited from RESTError

#code, #error, #message, #uri

Method Summary

Methods inherited from RESTError

register, registry, #to_s

Methods included from ClassUtilMixin

included