Exception: Twitter::NotAcceptableError
- Defined in:
- lib/twitter/core.rb
Overview
Runtime error leaf class raised when the format specified in the request is not understood by the Twitter.com API. HTTP code: 406 (aka Not Acceptable).
To handle specifically you would do the following: begin timeline = twitter.timeline_for(:friends, :since => tweet) rescue NotAcceptableError => nae
end